# -*- coding: utf-8 -*-

from django import template
from django.utils.html import escape
from django.utils.safestring import mark_safe
from kfet.models import Settings
from math import floor
import re

register = template.Library()


@register.filter()
def highlight_text(text, q):
    q2 = "|".join(re.escape(word) for word in q.split())
    pattern = re.compile(r"(?P<filter>%s)" % q2, re.IGNORECASE)
    regex = r"<span class='highlight_autocomplete'>\g<filter></span>"
    return mark_safe(re.sub(pattern, regex, escape(text)))


@register.filter(is_safe=True)
def highlight_user(user, q):
    if user.first_name and user.last_name:
        text = "%s %s (%s)" % (user.first_name, user.last_name, user.username)
    else:
        text = user.username
    return highlight_text(text, q)



@register.filter(is_safe=True)
def highlight_clipper(clipper, q):
    if clipper.fullname:
        text = "%s (%s)" % (clipper.fullname, clipper.clipper)
    else:
        text = clipper.clipper
    return highlight_text(text, q)



@register.filter()
def ukf(balance, is_cof):
    grant = is_cof and (1 + Settings.SUBVENTION_COF() / 100) or 1
    return floor(balance * 10 * grant)
